==> knative-client-4.6.3-sources.jar: io/fabric8/knative/client/serving/v1/internal/RevisionOperationsImpl.java <==

/**
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

                        

package io.fabric8.knative.client.serving.v1.internal;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.knative.serving.v1.DoneableRevision;
import io.fabric8.knative.serving.v1.Revision;
import io.fabric8.knative.serving.v1.RevisionList;
import io.fabric8.knative.serving.v1.DoneableRevision;

import java.util.Map;
import java.util.TreeMap;


public class RevisionOperationsImpl extends HasMetadataOperation<Revision, RevisionList, DoneableRevision, Resource<Revision, DoneableRevision>> {

  public RevisionOperationsImpl(OkHttpClient client, Config config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config));
  }

  public RevisionOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("serving.knative.dev")
    .withApiGroupVersion("v1")
    .withPlural("revisions"));
    this.type = Revision.class;
    this.listType = RevisionList.class;
    this.doneableType = DoneableRevision.class;
  }

  public RevisionOperationsImpl newInstance(OperationContext context) {
    return new RevisionOperationsImpl(context);
  }
}

==> knative-client-4.10.0-sources.jar: io/fabric8/knative/client/serving/v1/internal/RevisionOperationsImpl.java <==


                        

package io.fabric8.knative.client.serving.v1.internal;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.knative.serving.v1.DoneableRevision;
import io.fabric8.knative.serving.v1.Revision;
import io.fabric8.knative.serving.v1.RevisionList;
import io.fabric8.knative.serving.v1.DoneableRevision;

import java.util.Map;
import java.util.TreeMap;


public class RevisionOperationsImpl extends HasMetadataOperation<Revision, RevisionList, DoneableRevision, Resource<Revision, DoneableRevision>> {

  public RevisionOperationsImpl(OkHttpClient client, Config config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public RevisionOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("serving.knative.dev")
    .withApiGroupVersion("v1")
    .withPlural("revisions"));
    this.type = Revision.class;
    this.listType = RevisionList.class;
    this.doneableType = DoneableRevision.class;
  }

  public RevisionOperationsImpl newInstance(OperationContext context) {
    return new RevisionOperationsImpl(context);
  }
}
